@@ -1,13 +1,50 @@
+# stdlib
 import json
+import ssl
 
+# requests
 import requests
+from requests.adapters import HTTPAdapter
+from requests.packages.urllib3.poolmanager import PoolManager
 
+# keen exceptions
 from keen import exceptions
 
 
 __author__ = 'dkador'
 
 
+class HTTPMethods(object):
+
+    ''' HTTP methods that can be used with Keen's API. '''
+
+    GET = 'get'
+    POST = 'post'
+
+
+class KeenAdapter(HTTPAdapter):
+
+    ''' Adapt :py:mod:`requests` to Keen IO. '''
+
+    def init_poolmanager(self, connections, maxsize, block=False):
+
+        ''' Initialize pool manager with forced TLSv1 support. '''
+
+        self.poolmanager = PoolManager(num_pools=connections,
+                                       maxsize=maxsize,
+                                       block=block,
+                                       ssl_version=ssl.PROTOCOL_TLSv1)
+
+
+def fulfill(method, *args, **kwargs):
+
+    ''' Fulfill an HTTP request to Keen's API. '''
+
+    s = requests.Session()
+    s.mount('https://', KeenAdapter())
+    return getattr(s, method)(*args, **kwargs)
+
+
 class KeenApi(object):
     """
     Responsible for communicating with the Keen API. Used by multiple
@@ -21,9 +58,8 @@ class KeenApi(object):
 
     # self says it belongs to KeenApi/andOr is the object passed into KeenApi
     # __init__ create keenapi object whenever KeenApi class is invoked
-    def __init__(self, project_id,
-                 write_key=None, read_key=None,
-                 base_url=None, api_version=None):
+    def __init__(self, project_id, write_key=None, read_key=None,
+                 base_url=None, api_version=None, post_timeout=None):
         """
         Initializes a KeenApi object
 
@@ -44,6 +80,7 @@ class KeenApi(object):
             self.base_url = base_url
         if api_version:
             self.api_version = api_version
+        self.post_timeout = post_timeout
 
     def post_event(self, event):
         """
@@ -63,7 +100,7 @@ class KeenApi(object):
                                                        event.event_collection)
         headers = {"Content-Type": "application/json", "Authorization": self.write_key}
         payload = event.to_json()
-        response = requests.post(url, data=payload, headers=headers)
+        response = fulfill(HTTPMethods.POST, url, data=payload, headers=headers, timeout=self.post_timeout)
         if response.status_code != 201:
             error = response.json()
             raise exceptions.KeenApiError(error)
@@ -86,7 +123,7 @@ class KeenApi(object):
                                                    self.project_id)
         headers = {"Content-Type": "application/json", "Authorization": self.write_key}
         payload = json.dumps(events)
-        response = requests.post(url, data=payload, headers=headers)
+        response = fulfill(HTTPMethods.POST, url, data=payload, headers=headers, timeout=self.post_timeout)
         if response.status_code != 200:
             error = response.json()
             raise exceptions.KeenApiError(error)
@@ -108,7 +145,7 @@ class KeenApi(object):
 
         headers = {"Authorization": self.read_key}
         payload = params
-        response = requests.get(url, params=payload, headers=headers)
+        response = fulfill(HTTPMethods.GET, url, params=payload, headers=headers)
         if response.status_code != 200:
             error = response.json()
             raise exceptions.KeenApiError(error)
