@@ -183,7 +183,7 @@ class KeenClient(object):
         :param interval: string, the time interval used for measuring data over
         time example: "daily"
         :param filters: array of dict, contains the filters you'd like to apply to the data
-        example: {["property_name":"device", "operator":"eq", "property_value":"iPhone"}]
+        example: [{"property_name":"device", "operator":"eq", "property_value":"iPhone"}]
         :param group_by: string or array of strings, the name(s) of the properties you would
         like to group you results by.  example: "customer.id" or ["browser","operating_system"]
 
@@ -207,7 +207,7 @@ class KeenClient(object):
         :param interval: string, the time interval used for measuring data over
         time example: "daily"
         :param filters: array of dict, contains the filters you'd like to apply to the data
-        example: {["property_name":"device", "operator":"eq", "property_value":"iPhone"}]
+        example: [{"property_name":"device", "operator":"eq", "property_value":"iPhone"}]
         :param group_by: string or array of strings, the name(s) of the properties you would
         like to group you results by.  example: "customer.id" or ["browser","operating_system"]
 
@@ -231,7 +231,7 @@ class KeenClient(object):
         :param interval: string, the time interval used for measuring data over
         time example: "daily"
         :param filters: array of dict, contains the filters you'd like to apply to the data
-        example: {["property_name":"device", "operator":"eq", "property_value":"iPhone"}]
+        example: [{"property_name":"device", "operator":"eq", "property_value":"iPhone"}]
         :param group_by: string or array of strings, the name(s) of the properties you would
         like to group you results by.  example: "customer.id" or ["browser","operating_system"]
 
@@ -255,7 +255,7 @@ class KeenClient(object):
         :param interval: string, the time interval used for measuring data over
         time example: "daily"
         :param filters: array of dict, contains the filters you'd like to apply to the data
-        example: {["property_name":"device", "operator":"eq", "property_value":"iPhone"}]
+        example: [{"property_name":"device", "operator":"eq", "property_value":"iPhone"}]
         :param group_by: string or array of strings, the name(s) of the properties you would
         like to group you results by.  example: "customer.id" or ["browser","operating_system"]
 
@@ -279,7 +279,7 @@ class KeenClient(object):
         :param interval: string, the time interval used for measuring data over
         time example: "daily"
         :param filters: array of dict, contains the filters you'd like to apply to the data
-        example: {["property_name":"device", "operator":"eq", "property_value":"iPhone"}]
+        example: [{"property_name":"device", "operator":"eq", "property_value":"iPhone"}]
         :param group_by: string or array of strings, the name(s) of the properties you would
         like to group you results by.  example: "customer.id" or ["browser","operating_system"]
 
@@ -303,7 +303,7 @@ class KeenClient(object):
         :param interval: string, the time interval used for measuring data over
         time example: "daily"
         :param filters: array of dict, contains the filters you'd like to apply to the data
-        example: {["property_name":"device", "operator":"eq", "property_value":"iPhone"}]
+        example: [{"property_name":"device", "operator":"eq", "property_value":"iPhone"}]
         :param group_by: string or array of strings, the name(s) of the properties you would
         like to group you results by.  example: "customer.id" or ["browser","operating_system"]
 
@@ -327,7 +327,7 @@ class KeenClient(object):
         :param interval: string, the time interval used for measuring data over
         time example: "daily"
         :param filters: array of dict, contains the filters you'd like to apply to the data
-        example: {["property_name":"device", "operator":"eq", "property_value":"iPhone"}]
+        example: [{"property_name":"device", "operator":"eq", "property_value":"iPhone"}]
         :param group_by: string or array of strings, the name(s) of the properties you would
         like to group you results by.  example: "customer.id" or ["browser","operating_system"]
 
@@ -336,7 +336,7 @@ class KeenClient(object):
                                  interval=interval, filters=filters, group_by=group_by, target_property=target_property)
         return self.api.query("select_unique", params)
 
-    def extraction(self, event_collection, timeframe=None, timezone=None, filters=None, latest=None, email=None):
+    def extraction(self, event_collection, timeframe=None, timezone=None, filters=None, latest=None, email=None, property_names=None):
         """ Performs a data extraction
 
         Returns either a JSON object of events or a response
@@ -348,13 +348,13 @@ class KeenClient(object):
         :param timezone: int, the timezone you'd like to use for the timeframe
         and interval in seconds
         :param filters: array of dict, contains the filters you'd like to apply to the data
-        example: {["property_name":"device", "operator":"eq", "property_value":"iPhone"}]
+        example: [{"property_name":"device", "operator":"eq", "property_value":"iPhone"}]
         :param latest: int, the number of most recent records you'd like to return
         :param email: string, optional string containing an email address to email results to
-
+        :param property_names: string or list of strings, used to limit the properties returned
         """
         params = self.get_params(event_collection=event_collection, timeframe=timeframe, timezone=timezone,
-                                 filters=filters, latest=latest, email=email)
+                                 filters=filters, latest=latest, email=email, property_names=property_names)
         return self.api.query("extraction", params)
 
     def funnel(self, steps, timeframe=None, timezone=None):
@@ -390,7 +390,7 @@ class KeenClient(object):
         :param timezone: int, the timezone you'd like to use for the timeframe
         and interval in seconds
         :param filters: array of dict, contains the filters you'd like to apply to the data
-        example: {["property_name":"device", "operator":"eq", "property_value":"iPhone"}]
+        example: [{"property_name":"device", "operator":"eq", "property_value":"iPhone"}]
         :param group_by: string or array of strings, the name(s) of the properties you would
         like to group you results by.  example: "customer.id" or ["browser","operating_system"]
 
@@ -407,7 +407,8 @@ class KeenClient(object):
         return self.api.query("multi_analysis", params)
 
     def get_params(self, event_collection=None, timeframe=None, timezone=None, interval=None, filters=None,
-                   group_by=None, target_property=None, latest=None, email=None, analyses=None, steps=None):
+                   group_by=None, target_property=None, latest=None, email=None, analyses=None, steps=None,
+                   property_names=None):
         params = {}
         if event_collection:
             params["event_collection"] = event_collection
@@ -437,5 +438,7 @@ class KeenClient(object):
             params["analyses"] = json.dumps(analyses)
         if steps:
             params["steps"] = json.dumps(steps)
+        if property_names:
+        	params["property_names"] = json.dumps(property_names)
 
         return params
